@@ -9,57 +9,63 @@
         <translation>Automatische Spracherkennung</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="506"/>
+        <location filename="clipgrab.cpp" line="512"/>
         <source>Downloading update … %1/%2 MBytes</source>
         <translation>Update wird heruntergeladen … %1/%2 MByte</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="515"/>
+        <location filename="clipgrab.cpp" line="521"/>
         <source>There was an error while downloading the update.: %1</source>
         <translation>Beim Herunterladen des Updates ist ein Fehler aufgetreten: %1</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="529"/>
+        <location filename="clipgrab.cpp" line="535"/>
         <source>The fingerprint of the downloaded update file could not be verified: %1 should have been %2</source>
         <translation>Fehler beim Überprüfen der Integrität des Updates. Prüfsumme: %1 Erwartet: %2</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="541"/>
+        <location filename="clipgrab.cpp" line="547"/>
         <source>Could not open update file.</source>
         <translation>Das Update konnte nicht geöffnet werden.</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="579"/>
+        <location filename="clipgrab.cpp" line="585"/>
         <source>Unable to write to %1</source>
         <translation>Konnte Datei nicht speichern: %1</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="601"/>
+        <location filename="clipgrab.cpp" line="607"/>
+        <source>SSL error: %1 
+%2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="clipgrab.cpp" line="614"/>
         <source>Error downloading youtube-dl: %1</source>
         <translation>Fehler beim Herunterladen von youtube-dl: %1</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="791"/>
+        <location filename="clipgrab.cpp" line="805"/>
         <source>B</source>
         <translation>B</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="791"/>
+        <location filename="clipgrab.cpp" line="805"/>
         <source>KiB</source>
         <translation>KiB</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="791"/>
+        <location filename="clipgrab.cpp" line="805"/>
         <source>MiB</source>
         <translation>MiB</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="791"/>
+        <location filename="clipgrab.cpp" line="805"/>
         <source>GiB</source>
         <translation>GiB</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="791"/>
+        <location filename="clipgrab.cpp" line="805"/>
         <source>TiB</source>
         <translation>TiB</translation>
     </message>
@@ -159,97 +165,117 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="mainwindow.cpp" line="272"/>
+        <location filename="mainwindow.cpp" line="273"/>
         <source>Select Target</source>
         <translation>Zieldatei auswählen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="73"/>
+        <location filename="mainwindow.cpp" line="74"/>
         <source>Please wait while ClipGrab is loading information about the video ...</source>
         <translation>Einen Moment Geduld, während ClipGrab Informationen über das Video lädt ...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="326"/>
+        <location filename="mainwindow.cpp" line="327"/>
         <source>Please enter the link to the video you want to download in the field below.</source>
         <translation>Um ein Video herunterzuladen, musst Du den Video-Link in das Eingabefeld einfügen.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="332"/>
+        <location filename="mainwindow.cpp" line="333"/>
         <source>No downloadable video could be found.&lt;br /&gt;Maybe you have entered the wrong link or there is a problem with your connection.</source>
         <translation>Auf dieser Seite wurde leider kein Video gefunden.&lt;br /&gt; Vielleicht hast Du einen falschen Link eingegeben oder es liegt ein Problem mit Deiner Internetverbindung vor.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="414"/>
+        <location filename="mainwindow.cpp" line="415"/>
         <source>ClipGrab: Video discovered in your clipboard</source>
         <translation>ClipGrab: Video in der Zwischenablage</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="414"/>
+        <location filename="mainwindow.cpp" line="415"/>
         <source>ClipGrab has discovered the address of a compatible video in your clipboard. Click on this message to download it now.</source>
         <translation>ClipGrab hat den Link zu einem kompatiblen Video in der Zwischenablage gefunden. Hier klicken, um es jetzt herunterzuladen.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="504"/>
+        <location filename="mainwindow.cpp" line="499"/>
         <source>ClipGrab - Exit confirmation</source>
         <translation>ClipGrab - Sicherheitsabfrage</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="504"/>
+        <location filename="mainwindow.cpp" line="499"/>
         <source>There is still at least one download in progress.&lt;br /&gt;If you exit the program now, all downloads will be canceled and cannot be recovered later.&lt;br /&gt;Do you really want to quit ClipGrab now?</source>
         <translation>Es wird momentan noch mindestens ein Video heruntergeladen.&lt;br /&gt;Wird ClipGrab nun beendet, werden alle Downloads abgebrochen und können später nicht wiederhergestellt werden.&lt;br/&gt;Soll ClipGrab wirklich beendet werden?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="717"/>
+        <location filename="mainwindow.cpp" line="527"/>
+        <source>Download finished</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="527"/>
+        <source>Downloading and converting “%title” is now finished.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="529"/>
+        <source>All downloads finished</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="529"/>
+        <source>ClipGrab has finished downloading and converting all selected videos.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="683"/>
         <source>No results found.</source>
         <translation>Keine Ergebnisse gefunden.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="774"/>
+        <location filename="mainwindow.cpp" line="740"/>
         <source>&amp;Open downloaded file</source>
         <translation>&amp;Heruntergeladene Datei öffnen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="775"/>
+        <location filename="mainwindow.cpp" line="741"/>
         <source>Open &amp;target folder</source>
         <translation>&amp;Zielordner öffnen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="777"/>
+        <location filename="mainwindow.cpp" line="743"/>
         <source>&amp;Pause download</source>
         <translation>Download &amp;pausieren</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="778"/>
+        <location filename="mainwindow.cpp" line="744"/>
         <source>&amp;Restart download</source>
         <translation>Download &amp;neustarten</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="779"/>
+        <location filename="mainwindow.cpp" line="745"/>
         <source>&amp;Cancel download</source>
         <translation>Download &amp;abbrechen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="781"/>
+        <location filename="mainwindow.cpp" line="747"/>
         <source>Copy &amp;video link</source>
         <translation>Videolink &amp;kopieren</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="782"/>
+        <location filename="mainwindow.cpp" line="748"/>
         <source>Open video link in &amp;browser</source>
         <translation>Videolink im &amp;Browser öffnen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="785"/>
+        <location filename="mainwindow.cpp" line="751"/>
         <source>Resume download</source>
         <translation>Download &amp;fortsetzen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="798"/>
+        <location filename="mainwindow.cpp" line="764"/>
         <source>Show in &amp;Finder</source>
         <translation>Im &amp;Finder anzeigen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="375"/>
+        <location filename="mainwindow.cpp" line="376"/>
         <source>ClipGrab - Select target path</source>
         <translation>ClipGrab - Zielverzeichnis auswählen</translation>
     </message>
@@ -267,188 +293,188 @@
         <translation>Downloads</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="331"/>
+        <location filename="mainwindow.ui" line="343"/>
         <source>Current Downloads:</source>
         <translation>Momentane Downloads:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="386"/>
+        <location filename="mainwindow.ui" line="398"/>
         <source>General</source>
         <translation>Allgemein</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="441"/>
+        <location filename="mainwindow.ui" line="453"/>
         <source>Here you can configure where the downloaded videos are to be saved.</source>
         <translation>Hier kann festgelegt werden, wo ClipGrab heruntergeladene Videos speichern soll.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="448"/>
+        <location filename="mainwindow.ui" line="460"/>
         <source>Browse ...</source>
         <translation>Durchsuchen ...</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="510"/>
+        <location filename="mainwindow.ui" line="522"/>
         <source>Clipboard</source>
         <translation>Zwischenablage</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="537"/>
+        <location filename="mainwindow.ui" line="549"/>
         <source>Always ask</source>
         <translation>Immer nachfragen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="530"/>
+        <location filename="mainwindow.ui" line="542"/>
         <source>Never download</source>
         <translation>Nichts</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="361"/>
+        <location filename="mainwindow.ui" line="373"/>
         <source>Pause selected download</source>
         <translation>Pausieren</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="410"/>
+        <location filename="mainwindow.ui" line="422"/>
         <source>Here you can adjust some general settings concerning the behaviour of ClipGrab.</source>
         <translation>Hier können allgemeine Einstellungen vorgenommen werden.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="421"/>
+        <location filename="mainwindow.ui" line="433"/>
         <source>Target Path</source>
         <translation>Zielordner</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="427"/>
+        <location filename="mainwindow.ui" line="439"/>
         <source>Always save at the last used path.</source>
         <translation>Immer den zuletzt gewählten Ordner verwenden.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="455"/>
+        <location filename="mainwindow.ui" line="467"/>
         <source>Never ask for file name</source>
         <translation>Nicht nach dem Dateinamen fragen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="476"/>
+        <location filename="mainwindow.ui" line="488"/>
         <source>Metadata</source>
         <translation>Metadaten</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="482"/>
+        <location filename="mainwindow.ui" line="494"/>
         <source>Here you can configure if ClipGrab is supposed to add metadata (ID3 tags) to your mp3 files.</source>
         <translation>Wenn für MP3-Dateien Metadaten (ID3-Tags) verwendet werden sollen, kann dies hier eingestellt werden.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="489"/>
+        <location filename="mainwindow.ui" line="501"/>
         <source>Use metadata</source>
         <translation>Metadaten benutzen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="516"/>
+        <location filename="mainwindow.ui" line="528"/>
         <source>Here you can configure how ClipGrab behaves when a downloadable video is discovered in your clipboard.</source>
         <translation>Welche Aktion soll ClipGrab durchführen, wenn ein Link zu einem Video in der Zwischenablage gefunden wurde?</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="523"/>
+        <location filename="mainwindow.ui" line="535"/>
         <source>Always download</source>
         <translation>Immer herunterladen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="558"/>
+        <location filename="mainwindow.ui" line="570"/>
         <source>Notifications</source>
         <translation>Benachrichtigungen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="564"/>
+        <location filename="mainwindow.ui" line="576"/>
         <source>After each download</source>
         <translation>Nach jedem Download</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="571"/>
+        <location filename="mainwindow.ui" line="583"/>
         <source>After all downloads have been completed</source>
         <translation>Nachdem alle Downloads abgeschlossen sind</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="591"/>
+        <location filename="mainwindow.ui" line="603"/>
         <source>Here you can configure when ClipGrab is supposed to display notifications.</source>
         <translation>Hier kann eingestellt werden, wann ClipGrab Benachrichtigungen anzeigen soll.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="598"/>
+        <location filename="mainwindow.ui" line="610"/>
         <source>Never</source>
         <translation>Nie</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="606"/>
+        <location filename="mainwindow.ui" line="618"/>
         <source>Proxy</source>
         <translation>Proxy</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="612"/>
+        <location filename="mainwindow.ui" line="624"/>
         <source>Use a proxy server</source>
         <translation>Einen Proxy-Server verwenden</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="622"/>
+        <location filename="mainwindow.ui" line="634"/>
         <source>Proxy settings</source>
         <translation>Proxy-Einstellungen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="631"/>
+        <location filename="mainwindow.ui" line="643"/>
         <source>Hostname/IP:</source>
         <translation>Hostname/IP:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="638"/>
+        <location filename="mainwindow.ui" line="650"/>
         <source>Port:</source>
         <translation>Port:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="665"/>
+        <location filename="mainwindow.ui" line="677"/>
         <source>Proxy type:</source>
         <oldsource>Proxy type</oldsource>
         <translation>Proxy-Typ:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="673"/>
+        <location filename="mainwindow.ui" line="685"/>
         <source>HTTP Proxy</source>
         <translation>HTTP-Proxy</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="678"/>
+        <location filename="mainwindow.ui" line="690"/>
         <source>Socks5 Proxy</source>
         <translation>Socks5 Proxy</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="705"/>
+        <location filename="mainwindow.ui" line="717"/>
         <source>Proxy authentication</source>
         <translation>Proxy-Authentifizierung</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="711"/>
+        <location filename="mainwindow.ui" line="723"/>
         <source>Username:</source>
         <translation>Benutzername:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="728"/>
+        <location filename="mainwindow.ui" line="740"/>
         <source>Password:</source>
         <translation>Passwort:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="741"/>
+        <location filename="mainwindow.ui" line="753"/>
         <source>Proxy requires authentication</source>
         <translation>Proxy mit Authentifizierung</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="749"/>
+        <location filename="mainwindow.ui" line="761"/>
         <source>Other</source>
         <translation>Weiteres</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="776"/>
+        <location filename="mainwindow.ui" line="788"/>
         <source>Remove finished downloads from list</source>
         <translation>Abgeschlossene Downloads aus der Liste entfernen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1170"/>
+        <location filename="mainwindow.ui" line="1182"/>
         <source>&lt;h2&gt;Thanks&lt;/h2&gt;
 ClipGrab relies on the work of the Qt project, the ffmpeg team, and the youtube-dl team.&lt;br&gt;
 Visit &lt;a href=&quot;https://www.qt.io&quot;&gt;qt.io&lt;/a&gt;, &lt;a href=&quot;https://ffmpeg.org&quot;&gt;ffmpeg.org&lt;/a&gt;, and &lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt; for further information.</source>
@@ -457,114 +483,114 @@ ClipGrab wäre ohne die Arbeit des Qt.Project, des ffmpeg-Teams und des youtube-
 Besuche &lt;a href=&quot;https://www.qt.io&quot;&gt;qt.io&lt;/a&gt;, &lt;a href=&quot;https://ffmpeg.org&quot;&gt;ffmpeg.org&lt;/a&gt; und&lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt; für weitere Informationen.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="755"/>
+        <location filename="mainwindow.ui" line="767"/>
         <source>Minimize ClipGrab to the system tray</source>
         <translation>ClipGrab beim Minimieren in den Systray verkleinern</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="762"/>
+        <location filename="mainwindow.ui" line="774"/>
         <source>Use WebM if possible</source>
         <translation>Wenn möglich WebM-Format verwenden</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="769"/>
+        <location filename="mainwindow.ui" line="781"/>
         <source>Ignore SSL errors</source>
         <translation>SSL-Fehler ignorieren</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="796"/>
+        <location filename="mainwindow.ui" line="808"/>
         <source>Remember logins</source>
         <translation>Logins speichern</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="803"/>
+        <location filename="mainwindow.ui" line="815"/>
         <source>Remember video quality</source>
         <translation>Videoqualität speichern</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="815"/>
+        <location filename="mainwindow.ui" line="827"/>
         <source>Language</source>
         <translation>Sprache</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="839"/>
+        <location filename="mainwindow.ui" line="851"/>
         <source>Here you can change the language of ClipGrab.</source>
         <translation>Hier kann die Sprache der Benutzeroberfläche von ClipGrab eingestellt werden.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="846"/>
+        <location filename="mainwindow.ui" line="858"/>
         <source>Please select a language from the list below. You have to restart ClipGrab in order to apply you selection.</source>
         <translation>Bitte wähle eine Sprache aus der Liste aus. Damit die Änderungen aktiviert werden, muss ClipGrab neu gestartet werden.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="883"/>
+        <location filename="mainwindow.ui" line="895"/>
         <source>Conversion</source>
         <translation>Konvertierung</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="906"/>
+        <location filename="mainwindow.ui" line="918"/>
         <source>Experts can create custom presets for the video conversion here.</source>
         <translation>Experten können hier eigene Zielformate erstellen.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="913"/>
+        <location filename="mainwindow.ui" line="925"/>
         <source>Format preset</source>
         <translation>Zielformatbezeichnung</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="923"/>
+        <location filename="mainwindow.ui" line="935"/>
         <source>Add new preset</source>
         <translation>Neues Format erstellen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="930"/>
+        <location filename="mainwindow.ui" line="942"/>
         <source>Remove selected preset</source>
         <translation>Ausgewähltes Löschen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="953"/>
+        <location filename="mainwindow.ui" line="965"/>
         <source>Audio</source>
         <translation>Audio</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="965"/>
-        <location filename="mainwindow.ui" line="1017"/>
+        <location filename="mainwindow.ui" line="977"/>
+        <location filename="mainwindow.ui" line="1029"/>
         <source>Codec</source>
         <translation>Codec</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="991"/>
-        <location filename="mainwindow.ui" line="1079"/>
+        <location filename="mainwindow.ui" line="1003"/>
+        <location filename="mainwindow.ui" line="1091"/>
         <source>Bitrate (kb/s)</source>
         <translation>Bitrate (KB/s)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="998"/>
+        <location filename="mainwindow.ui" line="1010"/>
         <source>Disable Audio</source>
         <translation>Audio deaktivieren</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1008"/>
+        <location filename="mainwindow.ui" line="1020"/>
         <source>Video</source>
         <translation>Video</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1030"/>
+        <location filename="mainwindow.ui" line="1042"/>
         <source>Frames/second</source>
         <translation>Bilder/Sekunde</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1089"/>
+        <location filename="mainwindow.ui" line="1101"/>
         <source>Disable video</source>
         <translation>Video deaktivieren</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1104"/>
+        <location filename="mainwindow.ui" line="1116"/>
         <source>About</source>
         <translation>Über ClipGrab</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1153"/>
+        <location filename="mainwindow.ui" line="1165"/>
         <source>&lt;h2&gt;Translation&lt;/h2&gt;
 ClipGrab is already available in many languages. If ClipGrab has not been translated into your language yet and if you want to contribute a translation, please check &lt;a href=&quot;http://clipgrab.de/translate&quot;&gt;http://clipgrab.de/translate&lt;/a&gt; for further information.</source>
         <translation>&lt;h2&gt;Übersetzung&lt;/h2&gt;
@@ -576,17 +602,17 @@ ClipGrab ist schon in vielen Sprachen verfügbar. Wenn ClipGrab noch nicht in de
         <translation>Dieses Video herunterladen!</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="279"/>
+        <location filename="mainwindow.ui" line="291"/>
         <source>Format:</source>
         <translation>Format:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="228"/>
+        <location filename="mainwindow.ui" line="234"/>
         <source>Quality:</source>
         <translation>Qualität:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1110"/>
+        <location filename="mainwindow.ui" line="1122"/>
         <source>&lt;h2&gt;Support ClipGrab!&lt;/h2&gt;
 &lt;p&gt;Only with your support, ClipGrab can remain free software!&lt;br&gt;So if you like ClipGrab and also want to help ensuring its further development, please consider making a donation.&lt;/p&gt;</source>
         <translation>&lt;h2&gt;ClipGrab unterstützen!&lt;/h2&gt;
@@ -598,17 +624,17 @@ ClipGrab ist schon in vielen Sprachen verfügbar. Wenn ClipGrab noch nicht in de
         <translation>Um nach Videos bei YouTube zu suchen, kannst Du Suchbegriffe in das Eingabefeld eingeben.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="244"/>
+        <location filename="mainwindow.ui" line="250"/>
         <source>Please enter the link to the video you want to download in the field below.</source>
         <translation>Um ein Video herunterzuladen, musst Du den Video-Link in das Eingabefeld einfügen.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="341"/>
+        <location filename="mainwindow.ui" line="353"/>
         <source>Open the target folder of the selected download</source>
         <translation>Zielordner des ausgewählten Downloads öffnen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="351"/>
+        <location filename="mainwindow.ui" line="363"/>
         <source>Cancel selected download</source>
         <translation>Ausgewählten Download abbrechen</translation>
     </message>
@@ -618,7 +644,7 @@ ClipGrab ist schon in vielen Sprachen verfügbar. Wenn ClipGrab noch nicht in de
         <translation>Suchen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="373"/>
+        <location filename="mainwindow.ui" line="385"/>
         <source>Settings</source>
         <translation>Einstellungen</translation>
     </message>
@@ -763,7 +789,7 @@ Das Herunterladen von 1080p-Videos von YouTube wird nicht unterstützt.</transla
 <context>
     <name>video</name>
     <message>
-        <location filename="video.cpp" line="267"/>
+        <location filename="video.cpp" line="261"/>
         <source>unknown</source>
         <translation>unbekannt</translation>
     </message>
