@@ -9,57 +9,63 @@
         <translation>자동 언어 인식</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="506"/>
+        <location filename="clipgrab.cpp" line="512"/>
         <source>Downloading update … %1/%2 MBytes</source>
         <translation>업데이트 다운로드중     %1/%2 MBytes</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="515"/>
+        <location filename="clipgrab.cpp" line="521"/>
         <source>There was an error while downloading the update.: %1</source>
         <translation>업데이트를 다운로드하는 도중 오류가 발생하였습니다.: %1</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="529"/>
+        <location filename="clipgrab.cpp" line="535"/>
         <source>The fingerprint of the downloaded update file could not be verified: %1 should have been %2</source>
         <translation>다운로드된 업데이트 파일의 지문이 정확하지 않습니다.: %1 은 %2어야 합니다.</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="541"/>
+        <location filename="clipgrab.cpp" line="547"/>
         <source>Could not open update file.</source>
         <translation>업데이트 파일을 열 수 없습니다.</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="579"/>
+        <location filename="clipgrab.cpp" line="585"/>
         <source>Unable to write to %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="601"/>
+        <location filename="clipgrab.cpp" line="607"/>
+        <source>SSL error: %1 
+%2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="clipgrab.cpp" line="614"/>
         <source>Error downloading youtube-dl: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="791"/>
+        <location filename="clipgrab.cpp" line="805"/>
         <source>B</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="791"/>
+        <location filename="clipgrab.cpp" line="805"/>
         <source>KiB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="791"/>
+        <location filename="clipgrab.cpp" line="805"/>
         <source>MiB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="791"/>
+        <location filename="clipgrab.cpp" line="805"/>
         <source>GiB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="791"/>
+        <location filename="clipgrab.cpp" line="805"/>
         <source>TiB</source>
         <translation type="unfinished"></translation>
     </message>
@@ -159,97 +165,117 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="mainwindow.cpp" line="272"/>
+        <location filename="mainwindow.cpp" line="273"/>
         <source>Select Target</source>
         <translation>대상 선택</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="73"/>
+        <location filename="mainwindow.cpp" line="74"/>
         <source>Please wait while ClipGrab is loading information about the video ...</source>
         <translation>ClipGrab이 비디오 정보를 로드중입니다. 잠시만 기다려주세요...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="326"/>
+        <location filename="mainwindow.cpp" line="327"/>
         <source>Please enter the link to the video you want to download in the field below.</source>
         <translation>아래 입력란에 다운로드하실 비디오 링크를 입력하십시오.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="332"/>
+        <location filename="mainwindow.cpp" line="333"/>
         <source>No downloadable video could be found.&lt;br /&gt;Maybe you have entered the wrong link or there is a problem with your connection.</source>
         <translation>다운로드 할 수 있는 동영상을 찾을 수 없습니다.&lt;br /&gt;잘못된 링크를 입력했거나 연결에 문제가 있을 수 있습니다.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="375"/>
+        <location filename="mainwindow.cpp" line="376"/>
         <source>ClipGrab - Select target path</source>
         <translation>ClipGrab - 대상 경로 선택</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="414"/>
+        <location filename="mainwindow.cpp" line="415"/>
         <source>ClipGrab: Video discovered in your clipboard</source>
         <translation>ClipGrab: 클립보드에서 비디오 발견</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="414"/>
+        <location filename="mainwindow.cpp" line="415"/>
         <source>ClipGrab has discovered the address of a compatible video in your clipboard. Click on this message to download it now.</source>
         <translation>ClipGrab이 클립 보드에서 호환되는 비디오 주소를 발견했습니다. 이 메시지를 클릭하여 지금 다운로드 하십시오.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="504"/>
+        <location filename="mainwindow.cpp" line="499"/>
         <source>ClipGrab - Exit confirmation</source>
         <translation>ClipGrab - 나가기 확인</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="504"/>
+        <location filename="mainwindow.cpp" line="499"/>
         <source>There is still at least one download in progress.&lt;br /&gt;If you exit the program now, all downloads will be canceled and cannot be recovered later.&lt;br /&gt;Do you really want to quit ClipGrab now?</source>
         <translation>아직 진행중인 다운로드가 하나 이상 남아있습니다.&lt;br/&gt;지금 프로그램을 종료하면 모든 다운로드가 취소되고 나중에 복구 할 수 없습니다.&lt;br/&gt;정말로 ClipGrab을 종료 하시겠습니까?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="717"/>
+        <location filename="mainwindow.cpp" line="527"/>
+        <source>Download finished</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="527"/>
+        <source>Downloading and converting “%title” is now finished.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="529"/>
+        <source>All downloads finished</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="529"/>
+        <source>ClipGrab has finished downloading and converting all selected videos.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="683"/>
         <source>No results found.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="774"/>
+        <location filename="mainwindow.cpp" line="740"/>
         <source>&amp;Open downloaded file</source>
         <translation>&amp;다운로드된 파일 열기</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="775"/>
+        <location filename="mainwindow.cpp" line="741"/>
         <source>Open &amp;target folder</source>
         <translation>&amp;대상 폴더 열기</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="777"/>
+        <location filename="mainwindow.cpp" line="743"/>
         <source>&amp;Pause download</source>
         <translation>&amp;다운로드 정지</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="778"/>
+        <location filename="mainwindow.cpp" line="744"/>
         <source>&amp;Restart download</source>
         <translation>&amp;다운로드 재시작</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="779"/>
+        <location filename="mainwindow.cpp" line="745"/>
         <source>&amp;Cancel download</source>
         <translation>&amp;다운로드 취소</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="781"/>
+        <location filename="mainwindow.cpp" line="747"/>
         <source>Copy &amp;video link</source>
         <translation>&amp;비디오 링크 복사</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="782"/>
+        <location filename="mainwindow.cpp" line="748"/>
         <source>Open video link in &amp;browser</source>
         <translation>&amp;브라우저에서 비디오 링크 열기</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="785"/>
+        <location filename="mainwindow.cpp" line="751"/>
         <source>Resume download</source>
         <translation>다운로드 재개</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="798"/>
+        <location filename="mainwindow.cpp" line="764"/>
         <source>Show in &amp;Finder</source>
         <translatorcomment>윈도우즈 유저가 많으므로 파일탐색기로 번역함</translatorcomment>
         <translation>&amp;파일탐색기에서 보기</translation>
@@ -284,341 +310,341 @@
         <translation>이 클립 잡기!</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="228"/>
+        <location filename="mainwindow.ui" line="234"/>
         <source>Quality:</source>
         <translation>품질:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="244"/>
+        <location filename="mainwindow.ui" line="250"/>
         <source>Please enter the link to the video you want to download in the field below.</source>
         <translation>아래 입력란에 다운로드받을 비디오 링크를 입력해주세요.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="279"/>
+        <location filename="mainwindow.ui" line="291"/>
         <source>Format:</source>
         <translation>포맷:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="331"/>
+        <location filename="mainwindow.ui" line="343"/>
         <source>Current Downloads:</source>
         <translation>현재 다운로드:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="351"/>
+        <location filename="mainwindow.ui" line="363"/>
         <source>Cancel selected download</source>
         <translation>선택한 다운로드 취소</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="341"/>
+        <location filename="mainwindow.ui" line="353"/>
         <source>Open the target folder of the selected download</source>
         <translation>선택한 다운로드 대상폴더 열기</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="361"/>
+        <location filename="mainwindow.ui" line="373"/>
         <source>Pause selected download</source>
         <translation>선택한 다운로드 일시정지</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="373"/>
+        <location filename="mainwindow.ui" line="385"/>
         <source>Settings</source>
         <translation>설정</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="386"/>
+        <location filename="mainwindow.ui" line="398"/>
         <source>General</source>
         <translation>일반</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="410"/>
+        <location filename="mainwindow.ui" line="422"/>
         <source>Here you can adjust some general settings concerning the behaviour of ClipGrab.</source>
         <translation>ClipGrab의 동작과 관련된 일반 설정을 할 수 있습니다.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="421"/>
+        <location filename="mainwindow.ui" line="433"/>
         <source>Target Path</source>
         <translatorcomment>&apos;디렉토리&apos;도 사용할 수 있겠으나, 아직 한국에는 windows사용자가 훨씬 많으므로 &apos;폴더&apos;로 번역함.</translatorcomment>
         <translation>대상 폴더</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="427"/>
+        <location filename="mainwindow.ui" line="439"/>
         <source>Always save at the last used path.</source>
         <translation>항상 마지막으로 사용된 경로에 저장.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="441"/>
+        <location filename="mainwindow.ui" line="453"/>
         <source>Here you can configure where the downloaded videos are to be saved.</source>
         <translation>여기서 비디오가 다운로드될 경로를 설정 할 수 있습니다.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="448"/>
+        <location filename="mainwindow.ui" line="460"/>
         <source>Browse ...</source>
         <translation>찾아보기...</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="455"/>
+        <location filename="mainwindow.ui" line="467"/>
         <source>Never ask for file name</source>
         <translation>파일명을 묻지 않음</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="476"/>
+        <location filename="mainwindow.ui" line="488"/>
         <source>Metadata</source>
         <translation>메타데이터</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="482"/>
+        <location filename="mainwindow.ui" line="494"/>
         <source>Here you can configure if ClipGrab is supposed to add metadata (ID3 tags) to your mp3 files.</source>
         <translation>여기서 ClipGrab이 메타데이터(ID3 태그)를 mp3 파일에 추가 할 것인지 설정할 수 있습니다.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="489"/>
+        <location filename="mainwindow.ui" line="501"/>
         <source>Use metadata</source>
         <translation>메타데이터 사용</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="510"/>
+        <location filename="mainwindow.ui" line="522"/>
         <source>Clipboard</source>
         <translation>클립보드</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="516"/>
+        <location filename="mainwindow.ui" line="528"/>
         <source>Here you can configure how ClipGrab behaves when a downloadable video is discovered in your clipboard.</source>
         <translation>여기서 클립보드에서 다운로드 가능한 비디오가 발견되면 ClipGrab이 어떻게 반응할지 설정할 수 습니다.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="523"/>
+        <location filename="mainwindow.ui" line="535"/>
         <source>Always download</source>
         <translation>항상 다운로드</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="530"/>
+        <location filename="mainwindow.ui" line="542"/>
         <source>Never download</source>
         <translation>다운로드 안함</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="537"/>
+        <location filename="mainwindow.ui" line="549"/>
         <source>Always ask</source>
         <translation>항상 물어봄</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="558"/>
+        <location filename="mainwindow.ui" line="570"/>
         <source>Notifications</source>
         <translation>알림</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="564"/>
+        <location filename="mainwindow.ui" line="576"/>
         <source>After each download</source>
         <translation>각각 비디오가 다운로드될 때마다</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="571"/>
+        <location filename="mainwindow.ui" line="583"/>
         <source>After all downloads have been completed</source>
         <translation>모든 다운로드가 완료된 이후</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="591"/>
+        <location filename="mainwindow.ui" line="603"/>
         <source>Here you can configure when ClipGrab is supposed to display notifications.</source>
         <translation>여기서 ClipGrab이 알림을 어떻게 보여줄지 설정할 수 있습니다.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="598"/>
+        <location filename="mainwindow.ui" line="610"/>
         <source>Never</source>
         <translation>알리지 않음</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="606"/>
+        <location filename="mainwindow.ui" line="618"/>
         <source>Proxy</source>
         <translation>프록시</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="612"/>
+        <location filename="mainwindow.ui" line="624"/>
         <source>Use a proxy server</source>
         <translation>프록시 서버 사용</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="622"/>
+        <location filename="mainwindow.ui" line="634"/>
         <source>Proxy settings</source>
         <translation>프록시 설정</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="631"/>
+        <location filename="mainwindow.ui" line="643"/>
         <source>Hostname/IP:</source>
         <translation>호스트명/IP:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="638"/>
+        <location filename="mainwindow.ui" line="650"/>
         <source>Port:</source>
         <translation>포트:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="665"/>
+        <location filename="mainwindow.ui" line="677"/>
         <source>Proxy type:</source>
         <translation>프록시 유형:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="673"/>
+        <location filename="mainwindow.ui" line="685"/>
         <source>HTTP Proxy</source>
         <translation>HTTP 프록시</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="678"/>
+        <location filename="mainwindow.ui" line="690"/>
         <source>Socks5 Proxy</source>
         <translation>Socks5 프록시</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="705"/>
+        <location filename="mainwindow.ui" line="717"/>
         <source>Proxy authentication</source>
         <translation>프록시 인증</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="711"/>
+        <location filename="mainwindow.ui" line="723"/>
         <source>Username:</source>
         <translation>사용자명:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="728"/>
+        <location filename="mainwindow.ui" line="740"/>
         <source>Password:</source>
         <translation>비밀번호:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="741"/>
+        <location filename="mainwindow.ui" line="753"/>
         <source>Proxy requires authentication</source>
         <translation>프록시가 인증을 필요로합니다</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="749"/>
+        <location filename="mainwindow.ui" line="761"/>
         <source>Other</source>
         <translation>기타</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="776"/>
+        <location filename="mainwindow.ui" line="788"/>
         <source>Remove finished downloads from list</source>
         <translation>완료된 다운로드는 목록에서 삭제</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1170"/>
+        <location filename="mainwindow.ui" line="1182"/>
         <source>&lt;h2&gt;Thanks&lt;/h2&gt;
 ClipGrab relies on the work of the Qt project, the ffmpeg team, and the youtube-dl team.&lt;br&gt;
 Visit &lt;a href=&quot;https://www.qt.io&quot;&gt;qt.io&lt;/a&gt;, &lt;a href=&quot;https://ffmpeg.org&quot;&gt;ffmpeg.org&lt;/a&gt;, and &lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt; for further information.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="755"/>
+        <location filename="mainwindow.ui" line="767"/>
         <source>Minimize ClipGrab to the system tray</source>
         <translation>ClipGrab을 최소화하면 시스템 트레이로 이동</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="762"/>
+        <location filename="mainwindow.ui" line="774"/>
         <source>Use WebM if possible</source>
         <translation>WebM이 가능하다면 사용</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="769"/>
+        <location filename="mainwindow.ui" line="781"/>
         <source>Ignore SSL errors</source>
         <translation>SSL 오류 무시</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="796"/>
+        <location filename="mainwindow.ui" line="808"/>
         <source>Remember logins</source>
         <translation>로그인 기억하기</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="803"/>
+        <location filename="mainwindow.ui" line="815"/>
         <source>Remember video quality</source>
         <translation>비디오 품질 기억하기</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="815"/>
+        <location filename="mainwindow.ui" line="827"/>
         <source>Language</source>
         <translation>언어</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="839"/>
+        <location filename="mainwindow.ui" line="851"/>
         <source>Here you can change the language of ClipGrab.</source>
         <translation>여기서 ClipGrab의 언어를 변경할 수 있습니다.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="846"/>
+        <location filename="mainwindow.ui" line="858"/>
         <source>Please select a language from the list below. You have to restart ClipGrab in order to apply you selection.</source>
         <translation>언어를 선택해주세요. 선택을 적용하려면 ClipGrab을 다시 시작해야합니다.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="883"/>
+        <location filename="mainwindow.ui" line="895"/>
         <source>Conversion</source>
         <translation>변환</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="906"/>
+        <location filename="mainwindow.ui" line="918"/>
         <source>Experts can create custom presets for the video conversion here.</source>
         <translatorcomment>&apos;사전 설정&apos;이나 &apos;템플릿&apos;등으로 번역할 수도 있겠으나 원문을 존중하고, 비교적 잘 사용되는 언어로 보이므로 &apos;프리셋&apos;으로 음독번역하였음.</translatorcomment>
         <translation>여기서 비디오 변환을 위한 전문적인 사용자정의 프리셋을 만들 수 있습니다.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="913"/>
+        <location filename="mainwindow.ui" line="925"/>
         <source>Format preset</source>
         <translation>유형 프리셋</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="923"/>
+        <location filename="mainwindow.ui" line="935"/>
         <source>Add new preset</source>
         <translation>새로운 프리셋 추가</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="930"/>
+        <location filename="mainwindow.ui" line="942"/>
         <source>Remove selected preset</source>
         <translation>선택된 프리셋 제거</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="953"/>
+        <location filename="mainwindow.ui" line="965"/>
         <source>Audio</source>
         <translation>오디오</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="965"/>
-        <location filename="mainwindow.ui" line="1017"/>
+        <location filename="mainwindow.ui" line="977"/>
+        <location filename="mainwindow.ui" line="1029"/>
         <source>Codec</source>
         <translation>코덱</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="991"/>
-        <location filename="mainwindow.ui" line="1079"/>
+        <location filename="mainwindow.ui" line="1003"/>
+        <location filename="mainwindow.ui" line="1091"/>
         <source>Bitrate (kb/s)</source>
         <translation>비트레이트 (kb/s)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="998"/>
+        <location filename="mainwindow.ui" line="1010"/>
         <source>Disable Audio</source>
         <translation>오디오 비활성화</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1008"/>
+        <location filename="mainwindow.ui" line="1020"/>
         <source>Video</source>
         <translation>비디오</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1030"/>
+        <location filename="mainwindow.ui" line="1042"/>
         <source>Frames/second</source>
         <translation>프레임/초</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1089"/>
+        <location filename="mainwindow.ui" line="1101"/>
         <source>Disable video</source>
         <translation>비디오 비활성화</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1104"/>
+        <location filename="mainwindow.ui" line="1116"/>
         <source>About</source>
         <translatorcomment>해외에는 &apos;About&apos;자체가 많이 쓰이고 &apos;~에 대하여&apos; 소개하는 페이지로 대중화되어 있으나, 국내에서 그대로 사용하기에는 주어가 없어 이해하기 어려운 번역이됨. 따라서 프로그램 명칭을 붙여 &apos;ClipGrab에 대하여&apos;로 의역함</translatorcomment>
         <translation>ClipGrab에 대하여</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1110"/>
+        <location filename="mainwindow.ui" line="1122"/>
         <source>&lt;h2&gt;Support ClipGrab!&lt;/h2&gt;
 &lt;p&gt;Only with your support, ClipGrab can remain free software!&lt;br&gt;So if you like ClipGrab and also want to help ensuring its further development, please consider making a donation.&lt;/p&gt;</source>
         <translation>&lt;h2&gt;ClipGrab 지원하기!&lt;/h2&gt;
 &lt;p&gt;당신의 지원으로 ClipGrab은 자유 소프트웨어를 유지해 나갈 수 있습니다!&lt;br&gt;만약 ClipGrab을 좋아하고 발전을 돕고 싶다 생각하고 계시다면, 꼭 기부를 부탁드립니다.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1153"/>
+        <location filename="mainwindow.ui" line="1165"/>
         <source>&lt;h2&gt;Translation&lt;/h2&gt;
 ClipGrab is already available in many languages. If ClipGrab has not been translated into your language yet and if you want to contribute a translation, please check &lt;a href=&quot;http://clipgrab.de/translate&quot;&gt;http://clipgrab.de/translate&lt;/a&gt; for further information.</source>
         <translation>&lt;h2&gt;번역&lt;/h2&gt;
@@ -765,7 +791,7 @@ Youtube 1080p 비디오 다운로드가 지원되지 않습니다.</translation>
 <context>
     <name>video</name>
     <message>
-        <location filename="video.cpp" line="267"/>
+        <location filename="video.cpp" line="261"/>
         <source>unknown</source>
         <translation type="unfinished"></translation>
     </message>
